@@ -2,7 +2,6 @@
 using System;
 using System.Collections.Generic;
 using System.Text;
-using GConf.PropertyEditors;
 using Mono.Unix;
 
 using Tomboy.Sync;
@@ -20,9 +19,7 @@ namespace Tomboy
 		Gtk.Button resetSyncAddinButton;
 		Gtk.Button saveSyncAddinButton;
 		readonly AddinManager addin_manager;
-
-		Type current_extension;
-
+		
 		Gtk.Button font_button;
 		Gtk.Label font_face;
 		Gtk.Label font_size;
@@ -81,12 +78,27 @@ namespace Tomboy
 
 			notebook.AppendPage (MakeEditingPane (),
 			                     new Gtk.Label (Catalog.GetString ("Editing")));
-			notebook.AppendPage (MakeHotkeysPane (),
-			                     new Gtk.Label (Catalog.GetString ("Hotkeys")));
+			if (! (Services.Keybinder is NullKeybinder))
+				notebook.AppendPage (MakeHotkeysPane (),
+				                     new Gtk.Label (Catalog.GetString ("Hotkeys")));
 			notebook.AppendPage (MakeSyncPane (),
 			                     new Gtk.Label (Catalog.GetString ("Synchronization")));
 			notebook.AppendPage (MakeAddinsPane (),
 			                     new Gtk.Label (Catalog.GetString ("Add-ins")));
+			
+			// TODO: Figure out a way to have these be placed in a specific order
+			foreach (PreferenceTabAddin tabAddin in addin_manager.GetPreferenceTabAddins ()) {
+				Logger.Debug ("Adding preference tab addin: {0}", tabAddin.GetType ().Name);
+				try {
+					string tabName;
+					Gtk.Widget tabWidget;
+					if (tabAddin.GetPreferenceTabWidget (this, out tabName, out tabWidget) == true) {
+						notebook.AppendPage (tabWidget, new Gtk.Label (tabName));
+					}
+				} catch {
+					Logger.Warn ("Problems adding preferences tab addin: {0}", tabAddin.GetType ().Name);
+				}
+			}
 
 			VBox.PackStart (notebook, true, true, 0);
 
@@ -111,7 +123,7 @@ namespace Tomboy
 			AddActionWidget (button, Gtk.ResponseType.Close);
 			DefaultResponse = Gtk.ResponseType.Close;
 		}
-
+		
 		// Page 1
 		// List of editing options
 		public Gtk.Widget MakeEditingPane ()
@@ -119,7 +131,7 @@ namespace Tomboy
 			Gtk.Label label;
 			Gtk.CheckButton check;
 			Gtk.Alignment align;
-			PropertyEditorBool peditor, font_peditor, bullet_peditor;
+			IPropertyEditorBool peditor, font_peditor, bullet_peditor;
 
 			Gtk.VBox options_list = new Gtk.VBox (false, 12);
 			options_list.BorderWidth = 12;
@@ -134,7 +146,7 @@ namespace Tomboy
 				                Catalog.GetString ("_Spell check while typing"));
 				options_list.PackStart (check, false, false, 0);
 
-				peditor = new PropertyEditorToggleButton (
+				peditor = Services.Factory.CreatePropertyEditorToggleButton (
 				        Preferences.ENABLE_SPELLCHECKING,
 				        check);
 				SetupPropertyEditor (peditor);
@@ -154,7 +166,7 @@ namespace Tomboy
 			check = MakeCheckButton (Catalog.GetString ("Highlight _WikiWords"));
 			options_list.PackStart (check, false, false, 0);
 
-			peditor = new PropertyEditorToggleButton (Preferences.ENABLE_WIKIWORDS,
+			peditor = Services.Factory.CreatePropertyEditorToggleButton (Preferences.ENABLE_WIKIWORDS,
 			                check);
 			SetupPropertyEditor (peditor);
 
@@ -169,7 +181,7 @@ namespace Tomboy
 			check = MakeCheckButton (Catalog.GetString ("Enable auto-_bulleted lists"));
 			options_list.PackStart (check, false, false, 0);
 			bullet_peditor =
-			        new PropertyEditorToggleButton (Preferences.ENABLE_AUTO_BULLETED_LISTS,
+			        Services.Factory.CreatePropertyEditorToggleButton (Preferences.ENABLE_AUTO_BULLETED_LISTS,
 			                                        check);
 			SetupPropertyEditor (bullet_peditor);
 
@@ -179,7 +191,7 @@ namespace Tomboy
 			options_list.PackStart (check, false, false, 0);
 
 			font_peditor =
-			        new PropertyEditorToggleButton (Preferences.ENABLE_CUSTOM_FONT,
+			        Services.Factory.CreatePropertyEditorToggleButton (Preferences.ENABLE_CUSTOM_FONT,
 			                                        check);
 			SetupPropertyEditor (font_peditor);
 
@@ -192,7 +204,28 @@ namespace Tomboy
 			align.Add (font_button);
 
 			font_peditor.AddGuard (font_button);
+			
+			// New Note Template
+			// Translators: This is 'New Note' Template, not New 'Note Template'
+			label = MakeLabel (Catalog.GetString ("New Note Template"));
+			options_list.PackStart (label, false, false, 0);
 
+			label = MakeTipLabel (
+				Catalog.GetString ("Use the new note template to specify the text " +
+								   "that should be used when creating a new note."));
+			options_list.PackStart (label, false, false, 0);
+			
+			align = new Gtk.Alignment (0.5f, 0.5f, 0.4f, 1.0f);
+			align.Show ();
+			options_list.PackStart (align, false, false, 0);
+			
+			Gtk.LinkButton open_template_button = new Gtk.LinkButton (
+				String.Empty,
+				Catalog.GetString ("Open New Note Template"));
+
+			open_template_button.Clicked += OpenTemplateButtonClicked;
+			open_template_button.Show ();
+			align.Add (open_template_button);
 
 			return options_list;
 		}
@@ -235,8 +268,8 @@ namespace Tomboy
 			Gtk.CheckButton check;
 			Gtk.Alignment align;
 			Gtk.Entry entry;
-			PropertyEditorBool keybind_peditor;
-			PropertyEditor peditor;
+			IPropertyEditorBool keybind_peditor;
+			IPropertyEditor peditor;
 
 			Gtk.VBox hotkeys_list = new Gtk.VBox (false, 12);
 			hotkeys_list.BorderWidth = 12;
@@ -249,7 +282,7 @@ namespace Tomboy
 			hotkeys_list.PackStart (check, false, false, 0);
 
 			keybind_peditor =
-			        new PropertyEditorToggleButton (Preferences.ENABLE_KEYBINDINGS,
+			        Services.Factory.CreatePropertyEditorToggleButton (Preferences.ENABLE_KEYBINDINGS,
 			                                        check);
 			SetupPropertyEditor (keybind_peditor);
 
@@ -282,7 +315,7 @@ namespace Tomboy
 			entry.Show ();
 			table.Attach (entry, 1, 2, 0, 1);
 
-			peditor = new PropertyEditorEntry (Preferences.KEYBINDING_SHOW_NOTE_MENU,
+			peditor = Services.Factory.CreatePropertyEditorEntry (Preferences.KEYBINDING_SHOW_NOTE_MENU,
 			                                   entry);
 			SetupPropertyEditor (peditor);
 
@@ -299,7 +332,7 @@ namespace Tomboy
 			entry.Show ();
 			table.Attach (entry, 1, 2, 1, 2);
 
-			peditor = new PropertyEditorEntry (Preferences.KEYBINDING_OPEN_START_HERE,
+			peditor = Services.Factory.CreatePropertyEditorEntry (Preferences.KEYBINDING_OPEN_START_HERE,
 			                                   entry);
 			SetupPropertyEditor (peditor);
 
@@ -316,7 +349,7 @@ namespace Tomboy
 			entry.Show ();
 			table.Attach (entry, 1, 2, 2, 3);
 
-			peditor = new PropertyEditorEntry (Preferences.KEYBINDING_CREATE_NEW_NOTE,
+			peditor = Services.Factory.CreatePropertyEditorEntry (Preferences.KEYBINDING_CREATE_NEW_NOTE,
 			                                   entry);
 			SetupPropertyEditor (peditor);
 
@@ -333,7 +366,7 @@ namespace Tomboy
 			entry.Show ();
 			table.Attach (entry, 1, 2, 3, 4);
 
-			peditor = new PropertyEditorEntry (
+			peditor = Services.Factory.CreatePropertyEditorEntry (
 			        Preferences.KEYBINDING_OPEN_RECENT_CHANGES,
 			        entry);
 			SetupPropertyEditor (peditor);
@@ -352,7 +385,7 @@ namespace Tomboy
 
 			Gtk.HBox hbox = new Gtk.HBox (false, 4);
 
-			Gtk.Label label = new Gtk.Label (Catalog.GetString ("Service:"));
+			Gtk.Label label = new Gtk.Label (Catalog.GetString ("Ser_vice:"));
 			label.Xalign = 0;
 			label.Show ();
 			hbox.PackStart (label, false, false, 0);
@@ -369,6 +402,7 @@ namespace Tomboy
 			}
 
 			syncAddinCombo = new Gtk.ComboBox (syncAddinStore);
+			label.MnemonicWidget = syncAddinCombo;
 			Gtk.CellRendererText crt = new Gtk.CellRendererText ();
 			syncAddinCombo.PackStart (crt, true);
 			syncAddinCombo.SetCellDataFunc (crt,
@@ -424,7 +458,7 @@ namespace Tomboy
 			bbox.LayoutStyle = Gtk.ButtonBoxStyle.End;
 
 			// "Advanced..." button to bring up extra sync config dialog
-			Gtk.Button advancedConfigButton = new Gtk.Button (Catalog.GetString ("Advanced..."));
+			Gtk.Button advancedConfigButton = new Gtk.Button (Catalog.GetString ("_Advanced..."));
 			advancedConfigButton.Clicked += OnAdvancedSyncConfigButton;
 			advancedConfigButton.Show ();
 			bbox.PackStart (advancedConfigButton, false, false, 0);
@@ -757,7 +791,7 @@ namespace Tomboy
 			AddinInfoDialogDeleted (sender, null);
 		}
 
-		void SetupPropertyEditor (PropertyEditor peditor)
+		void SetupPropertyEditor (IPropertyEditor peditor)
 		{
 			// Ensure the key exists
 			Preferences.Get (peditor.Key);
@@ -1025,7 +1059,7 @@ namespace Tomboy
 				                                      "when you save new settings."));
 				int response = dialog.Run ();
 				dialog.Destroy ();
-				if (response == (int) Gtk.ResponseType.No)
+				if (response != (int) Gtk.ResponseType.Yes)
 					return;
 			} else { // FIXME: Weird place for this to go.  User should be able to cancel disabling of addin, anyway
 				HIGMessageDialog dialog =
@@ -1168,6 +1202,15 @@ namespace Tomboy
 				dialog.Destroy ();
 			}
 		}
+
+		void OpenTemplateButtonClicked (object sender, EventArgs args)
+		{
+			NoteManager manager = Tomboy.DefaultNoteManager;
+			Note template_note = manager.GetOrCreateTemplateNote ();
+
+			// Open the template note
+			template_note.Window.Show ();
+		}
 	}
 
 	// TODO: Figure out how to use Mono.Addins.Gui.AddinInfoDialog here instead.
