@@ -1,6 +1,7 @@
 
 using System;
 using System.Collections;
+using System.Collections.Generic;
 using System.Runtime.InteropServices;
 using System.Text;
 using System.IO;
@@ -439,7 +440,7 @@ namespace Tomboy
 		}
 	}
 
-	public class UriList : ArrayList
+	public class UriList : List<Uri>
 	{
 		public UriList (Note [] notes)
 		{
@@ -527,9 +528,20 @@ namespace Tomboy
 		static StringBuilder builder;
 		static StringWriter writer;
 		static XmlTextWriter xml;
+		static XmlWriterSettings documentSettings;
+		static XmlWriterSettings fragmentSettings;
 
 		static XmlEncoder ()
 		{
+			documentSettings = new XmlWriterSettings ();
+			documentSettings.NewLineChars = "\n";
+			documentSettings.Indent = true;
+
+			fragmentSettings = new XmlWriterSettings ();
+			fragmentSettings.NewLineChars = "\n";
+			fragmentSettings.Indent = true;
+			fragmentSettings.ConformanceLevel = ConformanceLevel.Fragment;
+
 			builder = new StringBuilder ();
 			writer = new StringWriter (builder);
 			xml = new XmlTextWriter (writer);
@@ -543,6 +555,16 @@ namespace Tomboy
 			builder.Length = 0;
 			return val;
 		}
+
+		public static XmlWriterSettings DocumentSettings
+		{
+			get { return documentSettings; }
+		}
+
+		public static XmlWriterSettings FragmentSettings
+		{
+			get { return fragmentSettings; }
+		}
 	}
 
 	// Strip xml tags
